@@ -692,14 +692,15 @@ def nlp_split(note,end_str,start_str):
     start_pos = 0
     end_pos = 0
     final_note = ""
+    len_note = len(note)
 
-    while end_pos <= len(note):
+    while end_pos <= len_note:
         start = note.find(start_str,start_pos)
         end = note.find(end_str,end_pos)
         note_part = note[start:end]
         final_note = final_note +"|"+ note_part
         if end < end_pos:
-            end = 100000
+            end = len_note
         start_pos = end
         end_pos = end+1
 
@@ -719,7 +720,7 @@ def nlp_cluster(data_df,cluster_column,clusters,prediction_col,max_df_val,min_df
 
     data_df[prediction_col] = labels
 
-    return data_df,model,X,vectorizer
+    return data_df,model,X,
 # =======================================================
 #
 # =======================================================
